@@ -5,7 +5,7 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'WebGraph-8xThermometer-MIB'}
   name => 'WebGraph-8xThermometer-MIB',
 };
 
-$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'WebGraph-8xThermometer-MIB'} = 
+$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'WebGraph-8xThermometer-MIB'} =
   '1.3.6.1.4.1.5040.1.2.6';
 
 $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'WebGraph-8xThermometer-MIB'} = {
@@ -30,6 +30,7 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'WebGraph-8xThermomete
   'wtWebioAn8GraphSessCntrl' => '1.3.6.1.4.1.5040.1.2.6.2',
   'wtWebioAn8GraphSessCntrlPassword' => '1.3.6.1.4.1.5040.1.2.6.2.1',
   'wtWebioAn8GraphSessCntrlConfigMode' => '1.3.6.1.4.1.5040.1.2.6.2.2',
+  'wtWebioAn8GraphSessCntrlConfigModeDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphSessCntrlConfigMode',
   'wtWebioAn8GraphSessCntrlLogout' => '1.3.6.1.4.1.5040.1.2.6.2.3',
   'wtWebioAn8GraphSessCntrlAdminPassword' => '1.3.6.1.4.1.5040.1.2.6.2.4',
   'wtWebioAn8GraphSessCntrlConfigPassword' => '1.3.6.1.4.1.5040.1.2.6.2.5',
@@ -49,13 +50,19 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'WebGraph-8xThermomete
   'wtWebioAn8GraphStTzOffsetMin' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.5',
   'wtWebioAn8GraphStTzEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.6',
   'wtWebioAn8GraphStTzStartMonth' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.7',
+  'wtWebioAn8GraphStTzStartMonthDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphStTzStartMonth',
   'wtWebioAn8GraphStTzStartMode' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.8',
+  'wtWebioAn8GraphStTzStartModeDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphStTzStartMode',
   'wtWebioAn8GraphStTzStartWday' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.9',
+  'wtWebioAn8GraphStTzStartWdayDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphStTzStartWday',
   'wtWebioAn8GraphStTzStartHrs' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.10',
   'wtWebioAn8GraphStTzStartMin' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.11',
   'wtWebioAn8GraphStTzStopMonth' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.12',
+  'wtWebioAn8GraphStTzStopMonthDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphStTzStopMonth',
   'wtWebioAn8GraphStTzStopMode' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.13',
+  'wtWebioAn8GraphStTzStopModeDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphStTzStopMode',
   'wtWebioAn8GraphStTzStopWday' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.14',
+  'wtWebioAn8GraphStTzStopWdayDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphStTzStopWday',
   'wtWebioAn8GraphStTzStopHrs' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.15',
   'wtWebioAn8GraphStTzStopMin' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.16',
   'wtWebioAn8GraphTimeServer' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.2',
@@ -68,6 +75,7 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'WebGraph-8xThermomete
   'wtWebioAn8GraphClockMin' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.3.2',
   'wtWebioAn8GraphClockDay' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.3.3',
   'wtWebioAn8GraphClockMonth' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.3.4',
+  'wtWebioAn8GraphClockMonthDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphClockMonth',
   'wtWebioAn8GraphClockYear' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.3.5',
   'wtWebioAn8GraphBasic' => '1.3.6.1.4.1.5040.1.2.6.3.1.3',
   'wtWebioAn8GraphNetwork' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.1',
@@ -85,7 +93,7 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'WebGraph-8xThermomete
   'wtWebioAn8GraphMailAdName' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.1',
   'wtWebioAn8GraphMailReply' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.2',
   'wtWebioAn8GraphMailServer' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.3',
-  'wtWebioAn8GraphMailEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.4',
+  'wtWebioAn1MailEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.4',
   'wtWebioAn8GraphMailAuthentication' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.5',
   'wtWebioAn8GraphMailAuthUser' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.6',
   'wtWebioAn8GraphMailAuthPassword' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.7',
@@ -115,10 +123,18 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'WebGraph-8xThermomete
   'wtWebioAn8GraphFTPEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.7.7',
   'wtWebioAn8GraphDatalogger' => '1.3.6.1.4.1.5040.1.2.6.3.1.4',
   'wtWebioAn8GraphLoggerTimebase' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.1',
+  'wtWebioAn8GraphLoggerTimebaseDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphLoggerTimebase',
   'wtWebioAn8GraphLoggerSensorSel' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.2',
+  'wtWebioAn8GraphDisplaySensorSel' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.3',
+  'wtWebioAn8GraphSensorColorTable' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.4',
+  'wtWebioAn8GraphSensorColorEntry' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.4.1',
+  'wtWebioAn8GraphSensorColor' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.4.1.1',
+  'wtWebioAn8GraphGraphicsSelectScale' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.4.1.2',
+  'wtWebioAn8GraphAutoScaleEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.5',
   'wtWebioAn8GraphVerticalUpperLimit' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.6',
   'wtWebioAn8GraphVerticalLowerLimit' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.7',
   'wtWebioAn8GraphHorizontalZoom' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.8',
+  'wtWebioAn8GraphHorizontalZoomDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphHorizontalZoom',
   'wtWebioAn8GraphAlarm' => '1.3.6.1.4.1.5040.1.2.6.3.1.5',
   'wtWebioAn8GraphAlarmCount' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.1',
   'wtWebioAn8GraphAlarmIfTable' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.2',
@@ -168,9 +184,6 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'WebGraph-8xThermomete
   'wtWebioAn8GraphGraphicsSelectDisplaySensorSel' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.2.1',
   'wtWebioAn8GraphGraphicsSelectDisplayShowExtrem' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.2.2',
   'wtWebioAn8GraphSensorColorTable' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.2.3',
-  'wtWebioAn8GraphSensorColorEntry' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.2.3.1',
-  'wtWebioAn8GraphGraphicsSensorColor' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.2.3.1.1',
-  'wtWebioAn8GraphGraphicsSelectScale' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.2.3.1.2',
   'wtWebioAn8GraphGraphicsScale' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3',
   'wtWebioAn8GraphGraphicsScaleAutoScaleEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.1',
   'wtWebioAn8GraphGraphicsScaleAutoFitEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.2',
@@ -212,7 +225,97 @@ $Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'WebGraph-8xThermomete
   'wtWebioAn8GraphDiagErrorClear' => '1.3.6.1.4.1.5040.1.2.6.4.5',
 };
 
-
-1;
-
-__END__
+$Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'WebGraph-8xThermometer-MIB'} = {
+  wtWebioAn8GraphStTzStartWday => {
+    '1' => 'wtWebioAn8GraphStartWday-Sunday',
+    '2' => 'wtWebioAn8GraphStartWday-Monday',
+    '3' => 'wtWebioAn8GraphStartWday-Tuesday',
+    '4' => 'wtWebioAn8GraphStartWday-Thursday',
+    '5' => 'wtWebioAn8GraphStartWday-Wednesday',
+    '6' => 'wtWebioAn8GraphStartWday-Friday',
+    '7' => 'wtWebioAn8GraphStartWday-Saturday',
+  },
+  wtWebioAn8GraphHorizontalZoom => {
+    '1' => 'wtWebioAn8GraphZoom-25min',
+    '2' => 'wtWebioAn8GraphZoom-75min',
+    '3' => 'wtWebioAn8GraphZoom-5hrs',
+    '4' => 'wtWebioAn8GraphZoom-30hrs',
+    '5' => 'wtWebioAn8GraphZoom-5days',
+    '6' => 'wtWebioAn8GraphZoom-25days',
+  },
+  wtWebioAn8GraphSessCntrlConfigMode => {
+    '0' => 'wtWebioAn8GraphSessCntrl-NoSession',
+    '1' => 'wtWebioAn8GraphSessCntrl-Session',
+  },
+  wtWebioAn8GraphStTzStopMonth => {
+    '1' => 'wtWebioAn8GraphStopMonth-January',
+    '2' => 'wtWebioAn8GraphStopMonth-February',
+    '3' => 'wtWebioAn8GraphStopMonth-March',
+    '4' => 'wtWebioAn8GraphStopMonth-April',
+    '5' => 'wtWebioAn8GraphStopMonth-May',
+    '6' => 'wtWebioAn8GraphStopMonth-June',
+    '7' => 'wtWebioAn8GraphStopMonth-July',
+    '8' => 'wtWebioAn8GraphStopMonth-August',
+    '9' => 'wtWebioAn8GraphStopMonth-September',
+    '10' => 'wtWebioAn8GraphStopMonth-October',
+    '11' => 'wtWebioAn8GraphStopMonth-November',
+    '12' => 'wtWebioAn8GraphStopMonth-December',
+  },
+  wtWebioAn8GraphStTzStopWday => {
+    '1' => 'wtWebioAn8GraphStopWday-Sunday',
+    '2' => 'wtWebioAn8GraphStopWday-Monday',
+    '3' => 'wtWebioAn8GraphStopWday-Tuesday',
+    '4' => 'wtWebioAn8GraphStopWday-Thursday',
+    '5' => 'wtWebioAn8GraphStopWday-Wednesday',
+    '6' => 'wtWebioAn8GraphStopWday-Friday',
+    '7' => 'wtWebioAn8GraphStopWday-Saturday',
+  },
+  wtWebioAn8GraphStTzStartMonth => {
+    '1' => 'wtWebioAn8GraphStartMonth-January',
+    '2' => 'wtWebioAn8GraphStartMonth-February',
+    '3' => 'wtWebioAn8GraphStartMonth-March',
+    '4' => 'wtWebioAn8GraphStartMonth-April',
+    '5' => 'wtWebioAn8GraphStartMonth-May',
+    '6' => 'wtWebioAn8GraphStartMonth-June',
+    '7' => 'wtWebioAn8GraphStartMonth-July',
+    '8' => 'wtWebioAn8GraphStartMonth-August',
+    '9' => 'wtWebioAn8GraphStartMonth-September',
+    '10' => 'wtWebioAn8GraphStartMonth-October',
+    '11' => 'wtWebioAn8GraphStartMonth-November',
+    '12' => 'wtWebioAn8GraphStartMonth-December',
+  },
+  wtWebioAn8GraphLoggerTimebase => {
+    '1' => 'wtWebioAn8GraphDatalogger-1Min',
+    '2' => 'wtWebioAn8GraphDatalogger-5Min',
+    '3' => 'wtWebioAn8GraphDatalogger-15Min',
+    '4' => 'wtWebioAn8GraphDatalogger-60Min',
+  },
+  wtWebioAn8GraphStTzStartMode => {
+    '1' => 'wtWebioAn8GraphStartMode-first',
+    '2' => 'wtWebioAn8GraphStartMode-second',
+    '3' => 'wtWebioAn8GraphStartMode-third',
+    '4' => 'wtWebioAn8GraphStartMode-fourth',
+    '5' => 'wtWebioAn8GraphStartMode-last',
+  },
+  wtWebioAn8GraphStTzStopMode => {
+    '1' => 'wtWebioAn8GraphStopMode-first',
+    '2' => 'wtWebioAn8GraphStopMode-second',
+    '3' => 'wtWebioAn8GraphStopMode-third',
+    '4' => 'wtWebioAn8GraphStopMode-fourth',
+    '5' => 'wtWebioAn8GraphStopMode-last',
+  },
+  wtWebioAn8GraphClockMonth => {
+    '1' => 'wtWebioAn8GraphClockMonth-January',
+    '2' => 'wtWebioAn8GraphClockMonth-February',
+    '3' => 'wtWebioAn8GraphClockMonth-March',
+    '4' => 'wtWebioAn8GraphClockMonth-April',
+    '5' => 'wtWebioAn8GraphClockMonth-May',
+    '6' => 'wtWebioAn8GraphClockMonth-June',
+    '7' => 'wtWebioAn8GraphClockMonth-July',
+    '8' => 'wtWebioAn8GraphClockMonth-August',
+    '9' => 'wtWebioAn8GraphClockMonth-September',
+    '10' => 'wtWebioAn8GraphClockMonth-October',
+    '11' => 'wtWebioAn8GraphClockMonth-November',
+    '12' => 'wtWebioAn8GraphClockMonth-December',
+  },
+};
